#!/usr/bin/env bash

report_dir=`mktemp -d`

LOG=${report_dir}/collect.log

function logmsg()
{
    echo -e [`date`] $* | tee -a ${LOG}
}

function my_cp()
{
    src=$1
    dest=$2

    logmsg "Copying ${src} to ${dest}"
    cp -r ${src} ${dest}
    rc=$?
    if [ ${rc} -ne 0 ]; then
        logmsg "Could not copy ${src} to ${dest} (${rc})"
    fi
}

function get_grub_cfg()
{
    if [ "${DIST}" == "SUSE" ]; then
        my_cp /boot/grub/menu.lst ${report_dir}
    elif [ "${DIST}" == "RHEL" ]; then
        my_cp /boot/grub/grub.conf ${report_dir}
    fi
}

function get_network_scripts()
{
    if [ "${DIST}" == "SUSE" ]; then
        my_cp /etc/sysconfig/network/ ${report_dir}
    elif [ "${DIST}" == "RHEL" ]; then
        my_cp /etc/sysconfig/network-scripts/ ${report_dir}
        my_cp /etc/sysconfig/network ${report_dir}
    fi
}

function get_network_info()
{
    get_network_scripts
    my_cp /etc/hosts ${report_dir}
    ifconfig -a > ${report_dir}/ifconfig_out
    route > ${report_dir}/route_out
}

function get_lvm_info
{
    pvdisplay > ${report_dir}/pvdisplay_out
    vgdisplay > ${report_dir}/vgdisplay_out
    lvdisplay > ${report_dir}/lvdisplay_out

    cfg=`find /etc/ -name lvm.conf`
    my_cp ${cfg} ${report_dir}
}

function get_storage_info()
{
    mount > ${report_dir}/mount_out
    my_cp /etc/fstab ${report_dir}
    get_lvm_info
    my_cp /etc/multipath.conf ${report_dir}
    my_cp /proc/partitions ${report_dir}
    df -ah > ${report_dir}/df_out
    lsblk > ${report_dir}/lsblk_out
    blkid > ${report_dir}/blkid_out
}

function get_dist_info()
{
    if [ "${DIST}" == "SUSE" ]; then
        my_cp /etc/SuSE-release ${report_dir}
    elif [ "${DIST}" == "RHEL" ]; then
        my_cp /etc/redhat-release ${report_dir}
        if [ -e /etc/centos-release ]; then
            my_cp /etc/centos-release ${report_dir}
        fi
    fi

    uname -a > ${report_dir}/uname_out

    my_cp /etc/issue ${report_dir}
    my_cp /proc/version ${report_dir}
}

function check_dist()
{
    found_suse=`grep -c "SUSE Linux Enterprise Server" /etc/issue`
    found_rhel=`grep -c "Red Hat Enterprise Linux Server" /etc/issue`
    found_centos=`grep -c "CentOS release" /etc/issue`

    if [ ${found_suse} -eq 1 ]; then
        DIST="SUSE"
    elif [ ${found_rhel} -eq 1 ]; then
        DIST="RHEL"
    elif [ ${found_centos} -eq 1 ]; then
        DIST="RHEL"
    fi
}

function get_app_info()
{
    rpm -qa | xargs rpm -qi > ${report_dir}/rpms_out
    ls -lR /etc/rc.d/ > ${report_dir}/services_out
    lsmod > ${report_dir}/lsmod_out
}

function get_mem_info()
{
    my_cp /proc/meminfo ${report_dir}
    my_cp /proc/swaps ${report_dir}
}


check_dist
logmsg "Collecting for dist = ${DIST}"

get_grub_cfg
get_network_info
get_storage_info
get_dist_info
get_app_info
get_mem_info

tar Pczf vm_info.tgz ${report_dir}
rm -rf ${report_dir}
logmsg "Collection is done"