#!/bin/sh

get_dist_id() {
  if command -v lsb_release >/dev/null 2>&1 ; then
    lsb_release -i -s | tr '[:upper:]' '[:lower:]'
  elif [ -f /etc/os-release ] ; then
    (. /etc/os-release && echo "${ID}" | tr '[:upper:]' '[:lower:]')
  fi
}

if [ ! -d /etc/cloud/cloud.cfg.d ] ; then
  return 0
fi

rm -f /etc/cloud/cloud.cfg.d/*azure*
rm -f /etc/cloud/cloud.cfg.d/*curtin*
rm -f /etc/cloud/cloud.cfg.d/*waagent*
rm -f /etc/cloud/cloud.cfg.d/*walinuxagent*
rm -f /etc/cloud/cloud.cfg.d/*aws*
rm -f /etc/cloud/cloud.cfg.d/*amazon*

# Add default DataSources
  cat > /etc/cloud/cloud.cfg.d/90_dpkg.cfg << EOF
datasource_list: [ NoCloud, ConfigDrive, OpenNebula, Azure, AltCloud, OVF, MAAS, GCE, OpenStack, CloudSigma, Ec2, CloudStack, SmartOS, None ]
EOF

# Override default DataSources
  cat > /etc/cloud/cloud.cfg.d/91_gce.cfg << EOF
datasource_list: [ GCE ]
EOF

if [ "$(get_dist_id)" = "ubuntu" ] ; then
  cat > /etc/cloud/cloud.cfg.d/91_gce_mirrors.cfg << EOF
system_info:
   package_mirrors:
     - arches: [i386, amd64]
       failsafe:
         primary: http://archive.ubuntu.com/ubuntu
         security: http://security.ubuntu.com/ubuntu
       search:
         primary:
           - http://%(region)s.gce.archive.ubuntu.com/ubuntu/
           - http://%(availability_zone)s.gce.clouds.archive.ubuntu.com/ubuntu/
           - http://gce.clouds.archive.ubuntu.com/ubuntu/
         security: []
     - arches: [armhf, armel, default]
       failsafe:
         primary: http://ports.ubuntu.com/ubuntu-ports
         security: http://ports.ubuntu.com/ubuntu-ports
EOF
fi

exit 0